@@ -71,6 +71,14 @@ def get_dataset(dataset_id):
 
 
 def register_model_version(model_id, desc, artifacts, mode=ModelRegisterMode.PYFUNC.value):
+    """
+    注册模型库版本
+    :param model_id: 模型ID
+    :param desc: 备注
+    :param artifacts: 注册文件路径，可以是文件夹,当为docker模式时，此处为docker-image,可以用save命令导出  eg：deployment.tar
+    :param mode: 注册模式,默认为自定义(ModelRegisterMode.PYFUNC.value)
+    :return:
+    """
     global _backend
     return _backend.register_model_version(model_id, desc, artifacts, mode)
 
@@ -83,3 +91,28 @@ def get_model(model_id):
     """
     global _backend
     return _backend.get_model(model_id)
+
+
+def download_dataset_artifact(dataset_id, path, type, destination):
+    """
+    获取模型对象
+    :param dataset_id:数据集ID
+    :param path:路径
+    :param type:数据集类型
+    :param destination:本地存储路径
+    :return:
+    """
+    global _backend
+    return _backend.download_dataset_artifact(dataset_id, path, destination)
+
+
+def download_dataset_artifacts(dataset_id, destination):
+    """
+    获取模型对象
+    :param dataset_id:数据集ID
+    :param type:数据集类型
+    :param destination:本地存储路径
+    :return:
+    """
+    global _backend
+    return _backend.download_dataset_artifacts(dataset_id, destination)
