@@ -6,7 +6,7 @@
 @license : (C) Copyright 2019-2022, Visionet(Tianjin)Information Technology Co.,Ltd.
 @Site    : plus.xiaobodata.com
 @File    : hosted_backend.py
-@Desc    : 
+@Desc    :
 """
 import logging
 import io
@@ -143,7 +143,9 @@ class HostedBackend(Backend):
         for entry in entries:
             fs = FileStream(entry)
             progress_indicator = SilentProgressIndicator(fs.length, fs.filename)
-            res = self._upload_raw_data(api_method=f'/data/dataset/{dataset_id}/asset', file=fs)
+            prefix = entry.prefix
+            res = self._upload_raw_data(api_method=f'/data/dataset/{dataset_id}/asset', file=fs,
+                                        data={"prefix": prefix.replace('\\', '/')})
             if res.json()["message"]:
                 f_count = f_count + 1
                 _logger.error(f"file {entry.source_path} upload failed,{res.json()['message']}")
@@ -215,8 +217,8 @@ class HostedBackend(Backend):
         url, destination, filename = urls
         destination_loc = os.path.join(destination, filename)
         with closing(requests.get(url, stream=True)) as response:
-            content_size = int(response.headers['content-length'])  # 内容体总大小
-
+            # content_size = int(response.headers['content-length'])  # 内容体总大小
+            content_size = len(response.content)
             progress_indicator = SilentProgressIndicator(content_size, filename)
             if content_size >= WARN_SIZE:
                 progress_indicator = LoggingProgressIndicator(content_size, filename)
@@ -234,11 +236,20 @@ class HostedBackend(Backend):
         :param destination:
         :return:
         """
-        pass
+        dataset = self.get_dataset(dataset_id)
+        dataset_type = dataset.data_type
+        name = dataset.name
+        self.download_dataset_artifact_(dataset_id, dataset_type, name, path, destination)
 
     @with_api_exceptions_handler
-    def download_dataset_artifacts(self, dataset_id, destination):
-
+    def download_dataset_artifact_(self, dataset_id, type, name, path, destination):
+        """
+        :param type
+        :param dataset_id:
+        :param path: 当数据集类型为timeseries时 path传参为 None
+        :param destination:
+        :return:
+        """
         if not destination:
             destination = os.getcwd()
 
@@ -248,21 +259,114 @@ class HostedBackend(Backend):
             raise NotADirectory(destination)
 
         try:
-            artifacts = self._list_dataset_artifacts(dataset_id)
-            urls = []
-            for asset in artifacts:
-                urls.append((asset.path, destination, asset.name))
-            pool.map(self._url_download, urls)
-            pool.close()
-            pool.join()
+            if type == 'timeseries':
+                self._timeseries_download(dataset_id, name, destination)
+            else:
+                urls = []
+                artifacts = self._list_dataset_artifacts(dataset_id)
+                if '.' not in path:
+                    resultinfo, dir = self._list_dir_artifacts(dataset_id, path, [], [])
+                    for i in dir:
+                        if not os.path.exists(destination + i):
+                            os.makedirs(destination + i)
+                    for asset in artifacts:
+                        for res in resultinfo:
+                            if asset.name in res:
+                                if '/' in res:
+                                    res = res.split('/' + asset.name)
+                                    res = res[0]
+                                urls.append((asset.path, destination + res, asset.name))
+                else:
+                    for asset in artifacts:
+                        if path in asset.path:
+                            urls.append((asset.path, destination, asset.name))
+                pool.map(self._url_download, urls)
+                pool.close()
+                pool.join()
         except Exception as e:
             raise e
 
+    @with_api_exceptions_handler
+    def download_dataset_artifacts(self, dataset_id, destination):
+        """
+        :param dataset_id:
+        :param destination:
+        :return:
+        """
+        dataset = self.get_dataset(dataset_id)
+        dataset_type = dataset.data_type
+        name = dataset.name
+        self.download_dataset_artifacts_(dataset_id, dataset_type, name, destination)
+
+    @with_api_exceptions_handler
+    def download_dataset_artifacts_(self, dataset_id, type, name, destination):
+        """
+        :param type 数据集类型
+        :param dataset_id:
+        :param destination:
+        :return:
+        """
+        if not destination:
+            destination = os.getcwd()
+
+        if not os.path.exists(destination):
+            os.makedirs(destination)
+        elif not os.path.isdir(destination):
+            raise NotADirectory(destination)
+
+        try:
+            if type == 'timeseries':
+                self._timeseries_download(dataset_id, name, destination)
+            else:
+                artifacts = self._list_dataset_artifacts(dataset_id)
+                resultinfo, dir = self._list_dir_artifacts(dataset_id=dataset_id, path=None, result=[], dir=[])
+                urls = []
+                for d in dir:
+                    if not os.path.exists(destination + d):
+                        os.makedirs(destination + d)
+                for asset in artifacts:
+                    for res in resultinfo:
+                        if res in asset.path:
+                            urls.append((asset.path, destination, asset.name))
+                pool.map(self._url_download, list(set(urls)))
+                pool.close()
+                pool.join()
+        except Exception as e:
+            raise e
+
+    @with_api_exceptions_handler
+    def _list_dir_artifacts(self, dataset_id, path, result, dir):
+        """
+        递归获取所有的文件，文件夹
+        :param dataset_id:
+        :path 文件路径
+        :return: 返回文件，图片数据集文件，文件夹列表
+        """
+        res = self._session.get(url=f'{self.api_address}/data/dataset/dir/{dataset_id}?path={path}')
+        if not path:
+            res = self._session.get(url=f'{self.api_address}/data/dataset/dir/{dataset_id}')
+        if res.json()["message"]:
+            raise Exception(res.json()["message"])
+        for d in res.json()['data']:
+            if d['isDir'] is True:
+                dir.append(d['path'])
+                self._list_dir_artifacts(dataset_id, d['path'], result, dir)
+            else:
+                if '/' in d['path'] and '.' in d['path']:
+                    dir_path = d['path'].split('/')
+                    dir_path.remove(dir_path[-1])
+                    dp = ''
+                    for p in dir_path:
+                        dp = dp + '/' + p
+                    dir.append(dp)
+                result.append(d['path'])
+        return list(set(result)), list(set(dir))
+
     @with_api_exceptions_handler
     def _list_dataset_artifacts(self, dataset_id):
         """
         :param dataset_id:
-        :return: 返回数据集文件列表
+        :return: 返回文件，图片数据集文件列表
         """
         res = self._session.get(url=f'{self.api_address}/data/dataset/{dataset_id}/asset?page=-1')
         if res.json()["message"]:
@@ -273,6 +377,29 @@ class HostedBackend(Backend):
                 Asset(art['id'], art['name'], art['path'], art['content_type'], art['size'], art['type'], dataset_id))
         return artifacts
 
+    @with_api_exceptions_handler
+    def _timeseries_download(self, dataset_id, name, destination):
+        """
+        时序数据整体下载
+        :param dataset_id:
+        :param destination
+        :return true or false
+        """
+        res = self._session.get(url=f'{self.api_address}/data/dataset/filedownload/device/{dataset_id}/all')
+        try:
+            destination_loc = os.path.join(destination, f'{name}.csv')
+            content_size = len(res.content)
+            progress_indicator = SilentProgressIndicator(content_size, f'{name}.csv')
+            if content_size >= WARN_SIZE:
+                progress_indicator = LoggingProgressIndicator(content_size, f'{name}.csv')
+            with open(destination_loc, 'wb') as f:
+                for data in res.iter_content(chunk_size=CHUNK_SIZE):
+                    progress_indicator.progress(CHUNK_SIZE)
+                    f.write(data)
+            progress_indicator.complete()
+        except Exception as e:
+            return e
+
     @with_api_exceptions_handler
     def create_model(self, app_id, name, desc):
         pass
@@ -374,11 +501,13 @@ class HostedBackend(Backend):
 
     def _upload_raw_data(self, api_method, file: FileStream, headers={}, data={}):
         url = self.api_address + api_method
-        res = self._session.post(url=url,
-                                 files=[('file', (
-                                     file.filename.replace(".\\", ""), open(file.fobj.name, 'rb'), file.content_type))],
-                                 data=data,
-                                 headers=headers)
+        with open(file.fobj.name, 'rb') as f:
+            res = self._session.post(url=url,
+                                     files=[('file', (
+                                         file.filename.replace(".\\", ""), f, file.content_type))],
+                                     data=data,
+                                     headers=headers,
+                                     )
         return res
 
     def _download_raw_data(self, api_method, headers, path_params, query_params):
