@@ -66,7 +66,7 @@ class Dataset(object):
                 dataset.download_asset('raw_data.csv', '/home/dataset/files/')
 
         """
-        return self._backend.download_asset(self.id, path, destination_dir)
+        return self._backend.download_dataset_artifact_(self.id, self.data_type, self.name, path, destination_dir)
 
     def download_artifacts(self, destination_dir=None):
         """Download all artifacts from the dataset.
@@ -92,7 +92,7 @@ class Dataset(object):
                 experiment.download_artifacts('/home/dataset/')
 
         """
-        return self._backend.download_dataset_artifacts(self.id, destination_dir)
+        return self._backend.download_dataset_artifacts_(self.id, self.data_type, self.name, destination_dir)
 
 
 class Asset(object):
