@@ -9,14 +9,17 @@
 @Desc    : 
 """
 
+BACKEND = 'WAVELETAI_BACKEND'
+
+API_URL = 'WAVELETAI_API_URL'
 
 API_KEY = ''
 
 API_TOKEN = ''
 
-USER_NAME = ''
+USER_NAME = 'WAVELETAI_USERNAME'
 
-USER_PWD = ''
+USER_PWD = 'WAVELETAI_PASSWORD'
 
 """单次请求最大值"""
 CHUNK_SIZE = 1024
